/* SerializablePropertyValueListTest.c generated by valac 0.34.6, the Vala compiler
 * generated from SerializablePropertyValueListTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; tab-width: 2 -*- */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST (serializable_property_value_list_test_get_type ())
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST, SerializablePropertyValueListTest))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST, SerializablePropertyValueListTestClass))
#define IS_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST))
#define IS_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST, SerializablePropertyValueListTestClass))

typedef struct _SerializablePropertyValueListTest SerializablePropertyValueListTest;
typedef struct _SerializablePropertyValueListTestClass SerializablePropertyValueListTestClass;
typedef struct _SerializablePropertyValueListTestPrivate SerializablePropertyValueListTestPrivate;

#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST (serializable_property_value_list_test_value_list_get_type ())
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueList))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueListClass))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_IS_VALUE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_IS_VALUE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueListClass))

typedef struct _SerializablePropertyValueListTestValueList SerializablePropertyValueListTestValueList;
typedef struct _SerializablePropertyValueListTestValueListClass SerializablePropertyValueListTestValueListClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES (serializable_property_value_list_test_values_get_type ())
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES, SerializablePropertyValueListTestValues))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES, SerializablePropertyValueListTestValuesClass))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_IS_VALUES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_IS_VALUES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES))
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES, SerializablePropertyValueListTestValuesClass))

typedef struct _SerializablePropertyValueListTestValues SerializablePropertyValueListTestValues;
typedef struct _SerializablePropertyValueListTestValuesClass SerializablePropertyValueListTestValuesClass;

#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_TYPE_ENUM (serializable_property_value_list_test_values_enum_get_type ())
typedef struct _SerializablePropertyValueListTestValuesPrivate SerializablePropertyValueListTestValuesPrivate;
typedef struct _SerializablePropertyValueListTestValueListPrivate SerializablePropertyValueListTestValueListPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializablePropertyValueListTest {
	GXmlTest parent_instance;
	SerializablePropertyValueListTestPrivate * priv;
};

struct _SerializablePropertyValueListTestClass {
	GXmlTestClass parent_class;
};

typedef enum  {
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL1,
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL2
} SerializablePropertyValueListTestValuesEnum;

struct _SerializablePropertyValueListTestValues {
	GXmlSerializableValueList parent_instance;
	SerializablePropertyValueListTestValuesPrivate * priv;
};

struct _SerializablePropertyValueListTestValuesClass {
	GXmlSerializableValueListClass parent_class;
};

struct _SerializablePropertyValueListTestValueList {
	GXmlSerializableObjectModel parent_instance;
	SerializablePropertyValueListTestValueListPrivate * priv;
};

struct _SerializablePropertyValueListTestValueListClass {
	GXmlSerializableObjectModelClass parent_class;
};

struct _SerializablePropertyValueListTestValueListPrivate {
	GXmlSerializableValueList* _values;
	SerializablePropertyValueListTestValues* _vals;
	gint _integer;
	gchar* _name;
};


static gpointer serializable_property_value_list_test_parent_class = NULL;
static gpointer serializable_property_value_list_test_values_parent_class = NULL;
static gpointer serializable_property_value_list_test_value_list_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_property_value_list_test_get_type (void) G_GNUC_CONST;
enum  {
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_DUMMY_PROPERTY
};
void serializable_property_value_list_test_add_tests (void);
static void __lambda148_ (void);
GType serializable_property_value_list_test_value_list_get_type (void) G_GNUC_CONST;
SerializablePropertyValueListTestValueList* serializable_property_value_list_test_value_list_new (void);
SerializablePropertyValueListTestValueList* serializable_property_value_list_test_value_list_construct (GType object_type);
static void ___lambda148__gtest_func (void);
static void __lambda149_ (void);
void serializable_property_value_list_test_value_list_set_values (SerializablePropertyValueListTestValueList* self, GXmlSerializableValueList* value);
GXmlSerializableValueList* serializable_property_value_list_test_value_list_get_values (SerializablePropertyValueListTestValueList* self);
static void ___lambda149__gtest_func (void);
static void __lambda150_ (void);
static void ___lambda150__gtest_func (void);
static void __lambda151_ (void);
static void ___lambda151__gtest_func (void);
static void __lambda152_ (void);
SerializablePropertyValueListTestValues* serializable_property_value_list_test_values_new (void);
SerializablePropertyValueListTestValues* serializable_property_value_list_test_values_construct (GType object_type);
GType serializable_property_value_list_test_values_get_type (void) G_GNUC_CONST;
void serializable_property_value_list_test_value_list_set_vals (SerializablePropertyValueListTestValueList* self, SerializablePropertyValueListTestValues* value);
SerializablePropertyValueListTestValues* serializable_property_value_list_test_value_list_get_vals (SerializablePropertyValueListTestValueList* self);
GType serializable_property_value_list_test_values_enum_get_type (void) G_GNUC_CONST;
void serializable_property_value_list_test_values_select (SerializablePropertyValueListTestValues* self, SerializablePropertyValueListTestValuesEnum v);
gchar* serializable_property_value_list_test_values_get_string (SerializablePropertyValueListTestValues* self);
void serializable_property_value_list_test_values_set_string (SerializablePropertyValueListTestValues* self, const gchar* str);
static void ___lambda152__gtest_func (void);
static void __lambda153_ (void);
static void ___lambda153__gtest_func (void);
SerializablePropertyValueListTest* serializable_property_value_list_test_new (void);
SerializablePropertyValueListTest* serializable_property_value_list_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
enum  {
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_DUMMY_PROPERTY
};
static GObject * serializable_property_value_list_test_values_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
#define SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueListPrivate))
enum  {
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_DUMMY_PROPERTY,
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALUES,
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALS,
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_INTEGER,
	SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_NAME
};
static gchar* serializable_property_value_list_test_value_list_real_node_name (GXmlSerializableObjectModel* base);
static gchar* serializable_property_value_list_test_value_list_real_to_string (GXmlSerializableObjectModel* base);
gint serializable_property_value_list_test_value_list_get_integer (SerializablePropertyValueListTestValueList* self);
void serializable_property_value_list_test_value_list_set_integer (SerializablePropertyValueListTestValueList* self, gint value);
const gchar* serializable_property_value_list_test_value_list_get_name (SerializablePropertyValueListTestValueList* self);
void serializable_property_value_list_test_value_list_set_name (SerializablePropertyValueListTestValueList* self, const gchar* value);
static void serializable_property_value_list_test_value_list_finalize (GObject* obj);
static void _vala_serializable_property_value_list_test_value_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_serializable_property_value_list_test_value_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1412 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = self;
#line 1413 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 198 "SerializablePropertyValueListTest.c"
}


static void __lambda148_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyValueListTestValueList* vl = NULL;
		SerializablePropertyValueListTestValueList* _tmp0_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlNode* _tmp2_ = NULL;
		GXmlNode* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlNode* _tmp9_ = NULL;
		GXmlElement* _tmp10_ = NULL;
		GXmlNode* evl1 = NULL;
		GXmlNode* _tmp11_ = NULL;
		GXmlNode* evl2 = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* s = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlNode* i = NULL;
		GXmlNode* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp0_ = serializable_property_value_list_test_value_list_new ();
#line 57 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		vl = _tmp0_;
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 58 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc = _tmp1_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) vl, (GXmlNode*) doc, &_inner_error_);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp3_ = _tmp2_;
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp3_);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc);
#line 59 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 250 "SerializablePropertyValueListTest.c"
			goto __catch36_g_error;
		}
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp4_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp5_ = _tmp4_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp6_ = g_strconcat ("XML:\n", _tmp5_, NULL);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp7_ = _tmp6_;
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp7_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp7_);
#line 60 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp5_);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp9_ = _tmp8_;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp9_) : NULL;
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp10_ == NULL) {
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp9_);
#line 277 "SerializablePropertyValueListTest.c"
		}
#line 61 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element = _tmp10_;
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp11_ = gxml_element_get_attr (element, "values");
#line 62 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl1 = _tmp11_;
#line 63 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (evl1 == NULL, "evl1 == null");
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp12_ = gxml_element_get_attr (element, "vals");
#line 64 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl2 = _tmp12_;
#line 65 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (evl2 == NULL, "evl2 == null");
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp13_ = gxml_element_get_attr (element, "name");
#line 66 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		s = _tmp13_;
#line 67 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14_ = gxml_element_get_attr (element, "integer");
#line 68 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		i = _tmp14_;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp15_ = gxml_node_get_value (i);
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp16_ = _tmp15_;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp17_ = _tmp16_;
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp17_, "0") == 0, "i.value == \"0\"");
#line 69 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp17_);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (i);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (s);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl2);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl1);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (vl);
#line 327 "SerializablePropertyValueListTest.c"
	}
	goto __finally36;
	__catch36_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		e = _inner_error_;
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_inner_error_ = NULL;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp18_ = e->message;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp19_ = string_to_string (_tmp18_);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp20_ = g_strconcat ("ERROR: ", _tmp19_, NULL);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp21_ = _tmp20_;
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp21_);
#line 71 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp21_);
#line 72 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_assert_not_reached ();
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_error_free0 (e);
#line 357 "SerializablePropertyValueListTest.c"
	}
	__finally36:
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_clear_error (&_inner_error_);
#line 56 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		return;
#line 368 "SerializablePropertyValueListTest.c"
	}
}


static void ___lambda148__gtest_func (void) {
#line 54 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	__lambda148_ ();
#line 376 "SerializablePropertyValueListTest.c"
}


static void __lambda149_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyValueListTestValueList* vl = NULL;
		SerializablePropertyValueListTestValueList* _tmp0_ = NULL;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlElement* element1 = NULL;
		GXmlGDocument* _tmp11_ = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlElement* _tmp14_ = NULL;
		GXmlNode* evl1 = NULL;
		GXmlElement* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlNode* _tmp17_ = NULL;
		GXmlNode* s1 = NULL;
		GXmlElement* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* i1 = NULL;
		GXmlElement* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp27_ = NULL;
		GXmlSerializableValueList* _tmp28_ = NULL;
		GXmlSerializableValueList* _tmp29_ = NULL;
		gchar* v = NULL;
		SerializablePropertyValueListTestValueList* _tmp30_ = NULL;
		GXmlSerializableValueList* _tmp31_ = NULL;
		GXmlSerializableValueList* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp35_ = NULL;
		GXmlSerializableValueList* _tmp36_ = NULL;
		GXmlSerializableValueList* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar** _tmp40_ = NULL;
		gchar** _tmp41_ = NULL;
		gint _tmp41__length1 = 0;
		SerializablePropertyValueListTestValueList* _tmp42_ = NULL;
		GXmlSerializableValueList* _tmp43_ = NULL;
		GXmlSerializableValueList* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		const gchar* _tmp46_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp47_ = NULL;
		GXmlSerializableValueList* _tmp48_ = NULL;
		GXmlSerializableValueList* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp52_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp53_ = NULL;
		GXmlGDocument* _tmp54_ = NULL;
		GXmlNode* _tmp55_ = NULL;
		GXmlNode* _tmp56_ = NULL;
		GXmlGDocument* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp62_ = NULL;
		GXmlNode* _tmp63_ = NULL;
		GXmlNode* _tmp64_ = NULL;
		GXmlElement* _tmp65_ = NULL;
		GXmlNode* evl2 = NULL;
		GXmlElement* _tmp66_ = NULL;
		GXmlNode* _tmp67_ = NULL;
		GXmlNode* _tmp68_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp69_ = NULL;
		GXmlSerializableValueList* _tmp70_ = NULL;
		GXmlSerializableValueList* _tmp71_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp72_ = NULL;
		GXmlSerializableValueList* _tmp73_ = NULL;
		GXmlSerializableValueList* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		const gchar* _tmp76_ = NULL;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp77_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp78_ = NULL;
		GXmlGDocument* _tmp79_ = NULL;
		GXmlNode* _tmp80_ = NULL;
		GXmlNode* _tmp81_ = NULL;
		GXmlGDocument* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		gchar* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp87_ = NULL;
		GXmlNode* _tmp88_ = NULL;
		GXmlNode* _tmp89_ = NULL;
		GXmlElement* _tmp90_ = NULL;
		GXmlNode* evl3 = NULL;
		GXmlElement* _tmp91_ = NULL;
		GXmlNode* _tmp92_ = NULL;
		GXmlNode* _tmp93_ = NULL;
		GXmlNode* _tmp94_ = NULL;
		gchar* _tmp95_ = NULL;
		gchar* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp98_ = NULL;
		GXmlSerializableValueList* _tmp99_ = NULL;
		GXmlSerializableValueList* _tmp100_ = NULL;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp101_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp102_ = NULL;
		GXmlGDocument* _tmp103_ = NULL;
		GXmlNode* _tmp104_ = NULL;
		GXmlNode* _tmp105_ = NULL;
		GXmlGDocument* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		gchar* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp111_ = NULL;
		GXmlNode* _tmp112_ = NULL;
		GXmlNode* _tmp113_ = NULL;
		GXmlElement* _tmp114_ = NULL;
		GXmlNode* evl4 = NULL;
		GXmlNode* _tmp115_ = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp0_ = serializable_property_value_list_test_value_list_new ();
#line 78 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		vl = _tmp0_;
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp1_ = gxml_gdocument_new ();
#line 79 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc1 = _tmp1_;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp2_ = vl;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp3_ = doc1;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp4_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp5_ = _tmp4_;
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp5_);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 80 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 540 "SerializablePropertyValueListTest.c"
			goto __catch37_g_error;
		}
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp6_ = doc1;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp7_ = gxml_gnode_to_string ((GXmlGNode*) _tmp6_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp8_ = _tmp7_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp9_ = g_strconcat ("XML1:\n", _tmp8_, NULL);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp10_ = _tmp9_;
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp10_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp10_);
#line 81 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp8_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp11_ = doc1;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) _tmp11_);
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp13_ = _tmp12_;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp14_ == NULL) {
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp13_);
#line 571 "SerializablePropertyValueListTest.c"
		}
#line 82 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element1 = _tmp14_;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp15_ = element1;
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp16_ = gxml_element_get_attr (_tmp15_, "values");
#line 83 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl1 = _tmp16_;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp17_ = evl1;
#line 84 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp17_ == NULL, "evl1 == null");
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp18_ = element1;
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "name");
#line 85 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		s1 = _tmp19_;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp20_ = s1;
#line 86 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp20_ == NULL, "s1 == null");
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp21_ = element1;
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp22_ = gxml_element_get_attr (_tmp21_, "integer");
#line 87 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		i1 = _tmp22_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp23_ = i1;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp24_ = gxml_node_get_value (_tmp23_);
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp25_ = _tmp24_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp26_ = _tmp25_;
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "0") == 0, "i1.value == \"0\"");
#line 88 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp26_);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp27_ = vl;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp28_ = gxml_serializable_value_list_new ();
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp29_ = _tmp28_;
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_values (_tmp27_, _tmp29_);
#line 90 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp29_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp30_ = vl;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp31_ = serializable_property_value_list_test_value_list_get_values (_tmp30_);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp32_ = _tmp31_;
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp33_ = gxml_serializable_value_list_get_value_at (_tmp32_, 0);
#line 91 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp33_;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp34_ = v;
#line 92 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp34_ == NULL, "v == null");
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp35_ = vl;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp36_ = serializable_property_value_list_test_value_list_get_values (_tmp35_);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp37_ = _tmp36_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp38_ = g_strdup ("Temp1");
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp39_ = g_strdup ("Temp2");
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_ = g_new0 (gchar*, 2 + 1);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_[0] = _tmp38_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_[1] = _tmp39_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41_ = _tmp40_;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41__length1 = 2;
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_value_list_add_values (_tmp37_, _tmp41_, 2);
#line 93 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41_ = (_vala_array_free (_tmp41_, _tmp41__length1, (GDestroyNotify) g_free), NULL);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp42_ = vl;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp43_ = serializable_property_value_list_test_value_list_get_values (_tmp42_);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp44_ = _tmp43_;
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp45_ = gxml_serializable_value_list_get_value_at (_tmp44_, 0);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 94 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp45_;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp46_ = v;
#line 95 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Temp1") == 0, "v == \"Temp1\"");
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp47_ = vl;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp48_ = serializable_property_value_list_test_value_list_get_values (_tmp47_);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp49_ = _tmp48_;
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp50_ = gxml_serializable_value_list_get_value_at (_tmp49_, 1);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 96 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp50_;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp51_ = v;
#line 97 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp51_, "Temp2") == 0, "v == \"Temp2\"");
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp52_ = gxml_gdocument_new ();
#line 98 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc2 = _tmp52_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp53_ = vl;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp54_ = doc2;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp55_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp53_, (GXmlNode*) _tmp54_, &_inner_error_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp56_ = _tmp55_;
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp56_);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc2);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_free0 (v);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (i1);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (s1);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl1);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element1);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 99 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 725 "SerializablePropertyValueListTest.c"
			goto __catch37_g_error;
		}
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp57_ = doc2;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp58_ = gxml_gnode_to_string ((GXmlGNode*) _tmp57_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp59_ = _tmp58_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp60_ = g_strconcat ("XML2:\n", _tmp59_, NULL);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp61_ = _tmp60_;
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp61_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp61_);
#line 100 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp59_);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp62_ = doc2;
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp63_ = gxml_document_get_root ((GXmlDocument*) _tmp62_);
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp64_ = _tmp63_;
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp65_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp64_) : NULL;
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp65_ == NULL) {
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp64_);
#line 756 "SerializablePropertyValueListTest.c"
		}
#line 101 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element2 = _tmp65_;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp66_ = element2;
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp67_ = gxml_element_get_attr (_tmp66_, "values");
#line 102 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl2 = _tmp67_;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp68_ = evl2;
#line 103 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp68_ == NULL, "evl2 == null");
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp69_ = vl;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp70_ = serializable_property_value_list_test_value_list_get_values (_tmp69_);
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp71_ = _tmp70_;
#line 105 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_value_list_select_value_at (_tmp71_, 1);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp72_ = vl;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp73_ = serializable_property_value_list_test_value_list_get_values (_tmp72_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp74_ = _tmp73_;
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp75_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp74_);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 106 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp75_;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp76_ = v;
#line 107 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp76_, "Temp2") == 0, "v == \"Temp2\"");
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp77_ = gxml_gdocument_new ();
#line 108 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc3 = _tmp77_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp78_ = vl;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp79_ = doc3;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp80_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp78_, (GXmlNode*) _tmp79_, &_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp81_ = _tmp80_;
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp81_);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc3);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl2);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element2);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc2);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_free0 (v);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (i1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (s1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 109 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 832 "SerializablePropertyValueListTest.c"
			goto __catch37_g_error;
		}
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp82_ = doc3;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp83_ = gxml_gnode_to_string ((GXmlGNode*) _tmp82_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp84_ = _tmp83_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp85_ = g_strconcat ("XML3:\n", _tmp84_, NULL);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp86_ = _tmp85_;
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp86_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp86_);
#line 110 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp84_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp87_ = doc3;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp88_ = gxml_document_get_root ((GXmlDocument*) _tmp87_);
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp89_ = _tmp88_;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp90_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp89_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp89_) : NULL;
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp90_ == NULL) {
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp89_);
#line 863 "SerializablePropertyValueListTest.c"
		}
#line 111 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element3 = _tmp90_;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp91_ = element3;
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp92_ = gxml_element_get_attr (_tmp91_, "values");
#line 112 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl3 = _tmp92_;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp93_ = evl3;
#line 113 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp93_ != NULL, "evl3 != null");
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp94_ = evl3;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp95_ = gxml_node_get_value (_tmp94_);
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp96_ = _tmp95_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp97_ = _tmp96_;
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp97_, "Temp2") == 0, "evl3.value == \"Temp2\"");
#line 114 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp97_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp98_ = vl;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp99_ = serializable_property_value_list_test_value_list_get_values (_tmp98_);
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp100_ = _tmp99_;
#line 116 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp100_, NULL);
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp101_ = gxml_gdocument_new ();
#line 117 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc4 = _tmp101_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp102_ = vl;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp103_ = doc4;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp104_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp102_, (GXmlNode*) _tmp103_, &_inner_error_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp105_ = _tmp104_;
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp105_);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc4);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl3);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element3);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc3);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl2);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element2);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc2);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_free0 (v);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (i1);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (s1);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl1);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element1);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 118 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 941 "SerializablePropertyValueListTest.c"
			goto __catch37_g_error;
		}
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp106_ = doc4;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp107_ = gxml_gnode_to_string ((GXmlGNode*) _tmp106_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp108_ = _tmp107_;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp109_ = g_strconcat ("XML4:\n", _tmp108_, NULL);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp110_ = _tmp109_;
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp110_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp110_);
#line 119 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp108_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp111_ = doc4;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp112_ = gxml_document_get_root ((GXmlDocument*) _tmp111_);
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp113_ = _tmp112_;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp114_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp113_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp113_) : NULL;
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp114_ == NULL) {
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp113_);
#line 972 "SerializablePropertyValueListTest.c"
		}
#line 120 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element4 = _tmp114_;
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp115_ = gxml_element_get_attr (element4, "values");
#line 121 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl4 = _tmp115_;
#line 122 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (evl4 == NULL, "evl4 == null");
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl4);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element4);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc4);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl3);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element3);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc3);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl2);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element2);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc2);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (i1);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (s1);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl1);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element1);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc1);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (vl);
#line 1014 "SerializablePropertyValueListTest.c"
	}
	goto __finally37;
	__catch37_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp116_ = NULL;
		const gchar* _tmp117_ = NULL;
		gchar* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		e = _inner_error_;
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_inner_error_ = NULL;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp116_ = e->message;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp117_ = string_to_string (_tmp116_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp118_ = g_strconcat ("ERROR: ", _tmp117_, NULL);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp119_ = _tmp118_;
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp119_);
#line 124 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp119_);
#line 125 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_assert_not_reached ();
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_error_free0 (e);
#line 1044 "SerializablePropertyValueListTest.c"
	}
	__finally37:
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_clear_error (&_inner_error_);
#line 77 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		return;
#line 1055 "SerializablePropertyValueListTest.c"
	}
}


static void ___lambda149__gtest_func (void) {
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	__lambda149_ ();
#line 1063 "SerializablePropertyValueListTest.c"
}


static void __lambda150_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		SerializablePropertyValueListTestValueList* vl = NULL;
		SerializablePropertyValueListTestValueList* _tmp1_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp4_ = NULL;
		GXmlSerializableValueList* _tmp5_ = NULL;
		GXmlSerializableValueList* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp9_ = NULL;
		GXmlSerializableValueList* _tmp10_ = NULL;
		GXmlSerializableValueList* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gchar** _tmp13_ = NULL;
		gchar** _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
		SerializablePropertyValueListTestValueList* _tmp15_ = NULL;
		GXmlSerializableValueList* _tmp16_ = NULL;
		GXmlSerializableValueList* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		SerializablePropertyValueListTestValueList* _tmp19_ = NULL;
		GXmlSerializableValueList* _tmp20_ = NULL;
		GXmlSerializableValueList* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar** _tmp23_ = NULL;
		gchar** _tmp24_ = NULL;
		gint _tmp24__length1 = 0;
		SerializablePropertyValueListTestValueList* _tmp25_ = NULL;
		GXmlSerializableValueList* _tmp26_ = NULL;
		GXmlSerializableValueList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gchar** _tmp29_ = NULL;
		gchar** _tmp30_ = NULL;
		gint _tmp30__length1 = 0;
		SerializablePropertyValueListTestValueList* _tmp31_ = NULL;
		GXmlSerializableValueList* _tmp32_ = NULL;
		GXmlSerializableValueList* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gchar** _tmp35_ = NULL;
		gchar** _tmp36_ = NULL;
		gint _tmp36__length1 = 0;
		SerializablePropertyValueListTestValueList* _tmp37_ = NULL;
		GXmlSerializableValueList* _tmp38_ = NULL;
		GXmlSerializableValueList* _tmp39_ = NULL;
		gboolean _tmp40_ = FALSE;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp0_ = gxml_gdocument_new_from_string ("<?xml version=\"1.0\"?>\n" \
"                       <options values=\"Temp1\"/>", 0, &_inner_error_);
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc1 = _tmp0_;
#line 131 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1123 "SerializablePropertyValueListTest.c"
			goto __catch38_g_error;
		}
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp1_ = serializable_property_value_list_test_value_list_new ();
#line 133 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		vl = _tmp1_;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp2_ = vl;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp3_ = doc1;
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp2_, (GXmlNode*) _tmp3_, &_inner_error_);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 134 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 1142 "SerializablePropertyValueListTest.c"
			goto __catch38_g_error;
		}
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp4_ = vl;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp5_ = serializable_property_value_list_test_value_list_get_values (_tmp4_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp6_ = _tmp5_;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp7_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp6_);
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp8_ = _tmp7_;
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Temp1") == 0, "vl.values.get_serializable_property_value () == \"Temp1\"");
#line 135 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp8_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp9_ = vl;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp10_ = serializable_property_value_list_test_value_list_get_values (_tmp9_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp11_ = _tmp10_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp13_ = gxml_serializable_value_list_get_values_array (_tmp11_, &_tmp12_);
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14_ = _tmp13_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14__length1 = _tmp12_;
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp14_ == NULL, "vl.values.get_values_array () == null");
#line 136 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14_ = (_vala_array_free (_tmp14_, _tmp14__length1, (GDestroyNotify) g_free), NULL);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp15_ = vl;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp16_ = serializable_property_value_list_test_value_list_get_values (_tmp15_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp17_ = _tmp16_;
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp18_ = gxml_serializable_value_list_is_value (_tmp17_);
#line 137 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp18_ == FALSE, "vl.values.is_value () == false");
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp19_ = vl;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp20_ = serializable_property_value_list_test_value_list_get_values (_tmp19_);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp21_ = _tmp20_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp22_ = g_strdup ("Temp1");
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp23_ = g_new0 (gchar*, 1 + 1);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp23_[0] = _tmp22_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp24_ = _tmp23_;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp24__length1 = 1;
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_value_list_add_values (_tmp21_, _tmp24_, 1);
#line 138 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp24_ = (_vala_array_free (_tmp24_, _tmp24__length1, (GDestroyNotify) g_free), NULL);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp25_ = vl;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp26_ = serializable_property_value_list_test_value_list_get_values (_tmp25_);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp27_ = _tmp26_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp29_ = gxml_serializable_value_list_get_values_array (_tmp27_, &_tmp28_);
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp30_ = _tmp29_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp30__length1 = _tmp28_;
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp30_ != NULL, "vl.values.get_values_array () != null");
#line 139 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp30_ = (_vala_array_free (_tmp30_, _tmp30__length1, (GDestroyNotify) g_free), NULL);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp31_ = vl;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp32_ = serializable_property_value_list_test_value_list_get_values (_tmp31_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp33_ = _tmp32_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp35_ = gxml_serializable_value_list_get_values_array (_tmp33_, &_tmp34_);
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp36_ = _tmp35_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp36__length1 = _tmp34_;
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp34_ == 1, "vl.values.get_values_array ().length == 1");
#line 140 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp36_ = (_vala_array_free (_tmp36_, _tmp36__length1, (GDestroyNotify) g_free), NULL);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp37_ = vl;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp38_ = serializable_property_value_list_test_value_list_get_values (_tmp37_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp39_ = _tmp38_;
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_ = gxml_serializable_value_list_is_value (_tmp39_);
#line 141 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp40_ == TRUE, "vl.values.is_value () == true");
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (vl);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc1);
#line 1251 "SerializablePropertyValueListTest.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		e = _inner_error_;
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_inner_error_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41_ = e->message;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp42_ = string_to_string (_tmp41_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp43_ = g_strconcat ("ERROR: ", _tmp42_, NULL);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp44_ = _tmp43_;
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp44_);
#line 143 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp44_);
#line 144 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_assert_not_reached ();
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_error_free0 (e);
#line 1281 "SerializablePropertyValueListTest.c"
	}
	__finally38:
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_clear_error (&_inner_error_);
#line 130 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		return;
#line 1292 "SerializablePropertyValueListTest.c"
	}
}


static void ___lambda150__gtest_func (void) {
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	__lambda150_ ();
#line 1300 "SerializablePropertyValueListTest.c"
}


static void __lambda151_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyValueListTestValueList* vl = NULL;
		SerializablePropertyValueListTestValueList* _tmp0_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp1_ = NULL;
		GXmlSerializableValueList* _tmp2_ = NULL;
		GXmlSerializableValueList* _tmp3_ = NULL;
		GXmlGDocument* doc1 = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp5_ = NULL;
		GXmlGDocument* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		GXmlNode* _tmp8_ = NULL;
		GXmlGDocument* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GXmlElement* element1 = NULL;
		GXmlGDocument* _tmp14_ = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlNode* _tmp16_ = NULL;
		GXmlElement* _tmp17_ = NULL;
		GXmlNode* evl1 = NULL;
		GXmlElement* _tmp18_ = NULL;
		GXmlNode* _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		GXmlNode* s1 = NULL;
		GXmlElement* _tmp21_ = NULL;
		GXmlNode* _tmp22_ = NULL;
		GXmlNode* _tmp23_ = NULL;
		GXmlNode* i1 = NULL;
		GXmlElement* _tmp24_ = NULL;
		GXmlNode* _tmp25_ = NULL;
		GXmlNode* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* v = NULL;
		SerializablePropertyValueListTestValueList* _tmp30_ = NULL;
		GXmlSerializableValueList* _tmp31_ = NULL;
		GXmlSerializableValueList* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp35_ = NULL;
		GXmlSerializableValueList* _tmp36_ = NULL;
		GXmlSerializableValueList* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar** _tmp40_ = NULL;
		gchar** _tmp41_ = NULL;
		gint _tmp41__length1 = 0;
		SerializablePropertyValueListTestValueList* _tmp42_ = NULL;
		GXmlSerializableValueList* _tmp43_ = NULL;
		GXmlSerializableValueList* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		const gchar* _tmp46_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp47_ = NULL;
		GXmlSerializableValueList* _tmp48_ = NULL;
		GXmlSerializableValueList* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
		GXmlGDocument* doc2 = NULL;
		GXmlGDocument* _tmp52_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp53_ = NULL;
		GXmlGDocument* _tmp54_ = NULL;
		GXmlNode* _tmp55_ = NULL;
		GXmlNode* _tmp56_ = NULL;
		GXmlGDocument* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		GXmlElement* element2 = NULL;
		GXmlGDocument* _tmp62_ = NULL;
		GXmlNode* _tmp63_ = NULL;
		GXmlNode* _tmp64_ = NULL;
		GXmlElement* _tmp65_ = NULL;
		GXmlNode* evl2 = NULL;
		GXmlElement* _tmp66_ = NULL;
		GXmlNode* _tmp67_ = NULL;
		GXmlNode* _tmp68_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp69_ = NULL;
		GXmlSerializableValueList* _tmp70_ = NULL;
		GXmlSerializableValueList* _tmp71_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp72_ = NULL;
		GXmlSerializableValueList* _tmp73_ = NULL;
		GXmlSerializableValueList* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		const gchar* _tmp76_ = NULL;
		GXmlGDocument* doc3 = NULL;
		GXmlGDocument* _tmp77_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp78_ = NULL;
		GXmlGDocument* _tmp79_ = NULL;
		GXmlNode* _tmp80_ = NULL;
		GXmlNode* _tmp81_ = NULL;
		GXmlGDocument* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		gchar* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		GXmlElement* element3 = NULL;
		GXmlGDocument* _tmp87_ = NULL;
		GXmlNode* _tmp88_ = NULL;
		GXmlNode* _tmp89_ = NULL;
		GXmlElement* _tmp90_ = NULL;
		GXmlNode* evl3 = NULL;
		GXmlElement* _tmp91_ = NULL;
		GXmlNode* _tmp92_ = NULL;
		GXmlNode* _tmp93_ = NULL;
		GXmlNode* _tmp94_ = NULL;
		gchar* _tmp95_ = NULL;
		gchar* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp98_ = NULL;
		GXmlSerializableValueList* _tmp99_ = NULL;
		GXmlSerializableValueList* _tmp100_ = NULL;
		GXmlGDocument* doc4 = NULL;
		GXmlGDocument* _tmp101_ = NULL;
		SerializablePropertyValueListTestValueList* _tmp102_ = NULL;
		GXmlGDocument* _tmp103_ = NULL;
		GXmlNode* _tmp104_ = NULL;
		GXmlNode* _tmp105_ = NULL;
		GXmlGDocument* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		gchar* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		GXmlElement* element4 = NULL;
		GXmlGDocument* _tmp111_ = NULL;
		GXmlNode* _tmp112_ = NULL;
		GXmlNode* _tmp113_ = NULL;
		GXmlElement* _tmp114_ = NULL;
		GXmlNode* evl4 = NULL;
		GXmlNode* _tmp115_ = NULL;
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp0_ = serializable_property_value_list_test_value_list_new ();
#line 150 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		vl = _tmp0_;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp1_ = vl;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp2_ = gxml_serializable_value_list_new ();
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp3_ = _tmp2_;
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_values (_tmp1_, _tmp3_);
#line 151 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp3_);
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp4_ = gxml_gdocument_new ();
#line 152 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc1 = _tmp4_;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp5_ = vl;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp6_ = doc1;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp7_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp5_, (GXmlNode*) _tmp6_, &_inner_error_);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp8_ = _tmp7_;
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp8_);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 153 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 1474 "SerializablePropertyValueListTest.c"
			goto __catch39_g_error;
		}
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp9_ = doc1;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp10_ = gxml_gnode_to_string ((GXmlGNode*) _tmp9_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp11_ = _tmp10_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp12_ = g_strconcat ("XML1:\n", _tmp11_, NULL);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp13_ = _tmp12_;
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp13_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp13_);
#line 154 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp11_);
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14_ = doc1;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp15_ = gxml_document_get_root ((GXmlDocument*) _tmp14_);
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp16_ = _tmp15_;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp16_) : NULL;
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp17_ == NULL) {
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp16_);
#line 1505 "SerializablePropertyValueListTest.c"
		}
#line 155 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element1 = _tmp17_;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp18_ = element1;
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp19_ = gxml_element_get_attr (_tmp18_, "values");
#line 156 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl1 = _tmp19_;
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp20_ = evl1;
#line 157 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp20_ == NULL, "evl1 == null");
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp21_ = element1;
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp22_ = gxml_element_get_attr (_tmp21_, "name");
#line 158 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		s1 = _tmp22_;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp23_ = s1;
#line 159 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp23_ == NULL, "s1 == null");
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp24_ = element1;
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp25_ = gxml_element_get_attr (_tmp24_, "integer");
#line 160 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		i1 = _tmp25_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp26_ = i1;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp27_ = gxml_node_get_value (_tmp26_);
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp28_ = _tmp27_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp29_ = _tmp28_;
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "0") == 0, "i1.value == \"0\"");
#line 161 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp29_);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp30_ = vl;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp31_ = serializable_property_value_list_test_value_list_get_values (_tmp30_);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp32_ = _tmp31_;
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp33_ = gxml_serializable_value_list_get_value_at (_tmp32_, 0);
#line 163 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp33_;
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp34_ = v;
#line 164 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp34_ == NULL, "v == null");
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp35_ = vl;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp36_ = serializable_property_value_list_test_value_list_get_values (_tmp35_);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp37_ = _tmp36_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp38_ = g_strdup ("Temp1");
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp39_ = g_strdup ("Temp2");
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_ = g_new0 (gchar*, 2 + 1);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_[0] = _tmp38_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp40_[1] = _tmp39_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41_ = _tmp40_;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41__length1 = 2;
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_value_list_add_values (_tmp37_, _tmp41_, 2);
#line 165 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp41_ = (_vala_array_free (_tmp41_, _tmp41__length1, (GDestroyNotify) g_free), NULL);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp42_ = vl;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp43_ = serializable_property_value_list_test_value_list_get_values (_tmp42_);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp44_ = _tmp43_;
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp45_ = gxml_serializable_value_list_get_value_at (_tmp44_, 0);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 166 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp45_;
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp46_ = v;
#line 167 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Temp1") == 0, "v == \"Temp1\"");
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp47_ = vl;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp48_ = serializable_property_value_list_test_value_list_get_values (_tmp47_);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp49_ = _tmp48_;
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp50_ = gxml_serializable_value_list_get_value_at (_tmp49_, 1);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 168 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp50_;
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp51_ = v;
#line 169 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp51_, "Temp2") == 0, "v == \"Temp2\"");
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp52_ = gxml_gdocument_new ();
#line 170 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc2 = _tmp52_;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp53_ = vl;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp54_ = doc2;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp55_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp53_, (GXmlNode*) _tmp54_, &_inner_error_);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp56_ = _tmp55_;
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp56_);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc2);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_free0 (v);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (i1);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (s1);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl1);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element1);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 171 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 1649 "SerializablePropertyValueListTest.c"
			goto __catch39_g_error;
		}
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp57_ = doc2;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp58_ = gxml_gnode_to_string ((GXmlGNode*) _tmp57_);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp59_ = _tmp58_;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp60_ = g_strconcat ("XML2:\n", _tmp59_, NULL);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp61_ = _tmp60_;
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp61_);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp61_);
#line 172 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp59_);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp62_ = doc2;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp63_ = gxml_document_get_root ((GXmlDocument*) _tmp62_);
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp64_ = _tmp63_;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp65_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp64_) : NULL;
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp65_ == NULL) {
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp64_);
#line 1680 "SerializablePropertyValueListTest.c"
		}
#line 173 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element2 = _tmp65_;
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp66_ = element2;
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp67_ = gxml_element_get_attr (_tmp66_, "values");
#line 174 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl2 = _tmp67_;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp68_ = evl2;
#line 175 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp68_ == NULL, "evl2 == null");
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp69_ = vl;
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp70_ = serializable_property_value_list_test_value_list_get_values (_tmp69_);
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp71_ = _tmp70_;
#line 177 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_value_list_select_value_at (_tmp71_, 1);
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp72_ = vl;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp73_ = serializable_property_value_list_test_value_list_get_values (_tmp72_);
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp74_ = _tmp73_;
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp75_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp74_);
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 178 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		v = _tmp75_;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp76_ = v;
#line 179 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp76_, "Temp2") == 0, "v == \"Temp2\"");
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp77_ = gxml_gdocument_new ();
#line 180 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc3 = _tmp77_;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp78_ = vl;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp79_ = doc3;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp80_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp78_, (GXmlNode*) _tmp79_, &_inner_error_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp81_ = _tmp80_;
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp81_);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc3);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl2);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element2);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc2);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_free0 (v);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (i1);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (s1);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl1);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element1);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 181 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 1756 "SerializablePropertyValueListTest.c"
			goto __catch39_g_error;
		}
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp82_ = doc3;
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp83_ = gxml_gnode_to_string ((GXmlGNode*) _tmp82_);
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp84_ = _tmp83_;
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp85_ = g_strconcat ("XML3:\n", _tmp84_, NULL);
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp86_ = _tmp85_;
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp86_);
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp86_);
#line 182 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp84_);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp87_ = doc3;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp88_ = gxml_document_get_root ((GXmlDocument*) _tmp87_);
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp89_ = _tmp88_;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp90_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp89_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp89_) : NULL;
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp90_ == NULL) {
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp89_);
#line 1787 "SerializablePropertyValueListTest.c"
		}
#line 183 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element3 = _tmp90_;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp91_ = element3;
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp92_ = gxml_element_get_attr (_tmp91_, "values");
#line 184 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl3 = _tmp92_;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp93_ = evl3;
#line 185 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp93_ != NULL, "evl3 != null");
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp94_ = evl3;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp95_ = gxml_node_get_value (_tmp94_);
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp96_ = _tmp95_;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp97_ = _tmp96_;
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp97_, "Temp2") == 0, "evl3.value == \"Temp2\"");
#line 186 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp97_);
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp98_ = vl;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp99_ = serializable_property_value_list_test_value_list_get_values (_tmp98_);
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp100_ = _tmp99_;
#line 188 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) _tmp100_, NULL);
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp101_ = gxml_gdocument_new ();
#line 189 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc4 = _tmp101_;
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp102_ = vl;
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp103_ = doc4;
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp104_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) _tmp102_, (GXmlNode*) _tmp103_, &_inner_error_);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp105_ = _tmp104_;
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp105_);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc4);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl3);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element3);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc3);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl2);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element2);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc2);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_free0 (v);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (i1);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (s1);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (evl1);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (element1);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc1);
#line 190 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 1865 "SerializablePropertyValueListTest.c"
			goto __catch39_g_error;
		}
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp106_ = doc4;
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp107_ = gxml_gnode_to_string ((GXmlGNode*) _tmp106_);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp108_ = _tmp107_;
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp109_ = g_strconcat ("XML4:\n", _tmp108_, NULL);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp110_ = _tmp109_;
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp110_);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp110_);
#line 191 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp108_);
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp111_ = doc4;
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp112_ = gxml_document_get_root ((GXmlDocument*) _tmp111_);
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp113_ = _tmp112_;
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp114_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp113_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp113_) : NULL;
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp114_ == NULL) {
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp113_);
#line 1896 "SerializablePropertyValueListTest.c"
		}
#line 192 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element4 = _tmp114_;
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp115_ = gxml_element_get_attr (element4, "values");
#line 193 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl4 = _tmp115_;
#line 194 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (evl4 == NULL, "evl4 == null");
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl4);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element4);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc4);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl3);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element3);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc3);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl2);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element2);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc2);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (v);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (i1);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (s1);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl1);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element1);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc1);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (vl);
#line 1938 "SerializablePropertyValueListTest.c"
	}
	goto __finally39;
	__catch39_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp116_ = NULL;
		const gchar* _tmp117_ = NULL;
		gchar* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		e = _inner_error_;
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_inner_error_ = NULL;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp116_ = e->message;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp117_ = string_to_string (_tmp116_);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp118_ = g_strconcat ("ERROR: ", _tmp117_, NULL);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp119_ = _tmp118_;
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp119_);
#line 196 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp119_);
#line 197 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_assert_not_reached ();
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_error_free0 (e);
#line 1968 "SerializablePropertyValueListTest.c"
	}
	__finally39:
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_clear_error (&_inner_error_);
#line 149 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		return;
#line 1979 "SerializablePropertyValueListTest.c"
	}
}


static void ___lambda151__gtest_func (void) {
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	__lambda151_ ();
#line 1987 "SerializablePropertyValueListTest.c"
}


static void __lambda152_ (void) {
	SerializablePropertyValueListTestValueList* v = NULL;
	SerializablePropertyValueListTestValueList* _tmp0_ = NULL;
	SerializablePropertyValueListTestValues* _tmp1_ = NULL;
	SerializablePropertyValueListTestValues* _tmp2_ = NULL;
	SerializablePropertyValueListTestValues* _tmp3_ = NULL;
	SerializablePropertyValueListTestValues* _tmp4_ = NULL;
	SerializablePropertyValueListTestValues* _tmp5_ = NULL;
	SerializablePropertyValueListTestValues* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	SerializablePropertyValueListTestValues* _tmp9_ = NULL;
	SerializablePropertyValueListTestValues* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	SerializablePropertyValueListTestValues* _tmp13_ = NULL;
	SerializablePropertyValueListTestValues* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	SerializablePropertyValueListTestValues* _tmp17_ = NULL;
	SerializablePropertyValueListTestValues* _tmp18_ = NULL;
	SerializablePropertyValueListTestValues* _tmp19_ = NULL;
	SerializablePropertyValueListTestValues* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	SerializablePropertyValueListTestValues* _tmp23_ = NULL;
	SerializablePropertyValueListTestValues* _tmp24_ = NULL;
	SerializablePropertyValueListTestValues* _tmp25_ = NULL;
	SerializablePropertyValueListTestValues* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	SerializablePropertyValueListTestValues* _tmp29_ = NULL;
	SerializablePropertyValueListTestValues* _tmp30_ = NULL;
	SerializablePropertyValueListTestValues* _tmp31_ = NULL;
	SerializablePropertyValueListTestValues* _tmp32_ = NULL;
	gchar* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	SerializablePropertyValueListTestValues* _tmp35_ = NULL;
	SerializablePropertyValueListTestValues* _tmp36_ = NULL;
	SerializablePropertyValueListTestValues* _tmp37_ = NULL;
	SerializablePropertyValueListTestValues* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	SerializablePropertyValueListTestValues* _tmp41_ = NULL;
	SerializablePropertyValueListTestValues* _tmp42_ = NULL;
	SerializablePropertyValueListTestValues* _tmp43_ = NULL;
	SerializablePropertyValueListTestValues* _tmp44_ = NULL;
	gchar* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	SerializablePropertyValueListTestValues* _tmp47_ = NULL;
	SerializablePropertyValueListTestValues* _tmp48_ = NULL;
	gchar* _tmp49_ = NULL;
	gchar* _tmp50_ = NULL;
	SerializablePropertyValueListTestValues* _tmp51_ = NULL;
	SerializablePropertyValueListTestValues* _tmp52_ = NULL;
	gboolean _tmp53_ = FALSE;
	SerializablePropertyValueListTestValues* _tmp54_ = NULL;
	SerializablePropertyValueListTestValues* _tmp55_ = NULL;
	SerializablePropertyValueListTestValues* _tmp56_ = NULL;
	SerializablePropertyValueListTestValues* _tmp57_ = NULL;
	gchar* _tmp58_ = NULL;
	gchar* _tmp59_ = NULL;
	SerializablePropertyValueListTestValues* _tmp60_ = NULL;
	SerializablePropertyValueListTestValues* _tmp61_ = NULL;
	gboolean _tmp62_ = FALSE;
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = serializable_property_value_list_test_value_list_new ();
#line 202 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	v = _tmp0_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp1_ = serializable_property_value_list_test_values_new ();
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp2_ = _tmp1_;
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	serializable_property_value_list_test_value_list_set_vals (v, _tmp2_);
#line 203 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_object_unref0 (_tmp2_);
#line 204 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp3_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 204 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp4_ = _tmp3_;
#line 204 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (_tmp4_ != NULL, "v.vals != null");
#line 205 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp5_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 205 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp6_ = _tmp5_;
#line 205 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp7_ = gxml_serializable_value_list_get_value_at ((GXmlSerializableValueList*) _tmp6_, 0);
#line 205 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp8_ = _tmp7_;
#line 205 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp8_, "Val1") == 0, "v.vals.get_value_at (0) == \"Val1\"");
#line 205 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp8_);
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp9_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp10_ = _tmp9_;
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp11_ = gxml_serializable_value_list_get_value_at ((GXmlSerializableValueList*) _tmp10_, 1);
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp12_ = _tmp11_;
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp12_, "Val2") == 0, "v.vals.get_value_at (1) == \"Val2\"");
#line 206 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp12_);
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp13_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp14_ = _tmp13_;
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp15_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp14_);
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp16_ = _tmp15_;
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (_tmp16_ == NULL, "v.vals.get_serializable_property_value () == null");
#line 207 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp16_);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp17_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp18_ = _tmp17_;
#line 208 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	gxml_serializable_value_list_select_value_at ((GXmlSerializableValueList*) _tmp18_, 0);
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp19_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp20_ = _tmp19_;
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp21_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp20_);
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp22_ = _tmp21_;
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp22_, "Val1") == 0, "v.vals.get_serializable_property_value () == \"Val1\"");
#line 209 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp22_);
#line 210 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp23_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 210 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp24_ = _tmp23_;
#line 210 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	gxml_serializable_value_list_select_value_at ((GXmlSerializableValueList*) _tmp24_, 1);
#line 211 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp25_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 211 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp26_ = _tmp25_;
#line 211 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp27_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp26_);
#line 211 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp28_ = _tmp27_;
#line 211 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp28_, "Val2") == 0, "v.vals.get_serializable_property_value () == \"Val2\"");
#line 211 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp28_);
#line 212 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp29_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 212 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp30_ = _tmp29_;
#line 212 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	gxml_serializable_value_list_select_value_at ((GXmlSerializableValueList*) _tmp30_, (gint) SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL1);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp31_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp32_ = _tmp31_;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp33_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp32_);
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp34_ = _tmp33_;
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp34_, "Val1") == 0, "v.vals.get_serializable_property_value () == \"Val1\"");
#line 213 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp34_);
#line 214 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp35_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 214 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp36_ = _tmp35_;
#line 214 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	gxml_serializable_value_list_select_value_at ((GXmlSerializableValueList*) _tmp36_, (gint) SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL2);
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp37_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp38_ = _tmp37_;
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp39_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) _tmp38_);
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp40_ = _tmp39_;
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp40_, "Val2") == 0, "v.vals.get_serializable_property_value () == \"Val2\"");
#line 215 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp40_);
#line 216 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp41_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 216 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp42_ = _tmp41_;
#line 216 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	serializable_property_value_list_test_values_select (_tmp42_, SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL1);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp43_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp44_ = _tmp43_;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp45_ = serializable_property_value_list_test_values_get_string (_tmp44_);
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp46_ = _tmp45_;
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp46_, "Val1") == 0, "v.vals.get_string () == \"Val1\"");
#line 217 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp46_);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp47_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp48_ = _tmp47_;
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp49_ = serializable_property_value_list_test_values_get_string (_tmp48_);
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp50_ = _tmp49_;
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp50_, "Val1") == 0, "v.vals.get_string () == \"Val1\"");
#line 218 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp50_);
#line 219 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp51_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 219 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp52_ = _tmp51_;
#line 219 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp53_ = gxml_serializable_value_list_is_value ((GXmlSerializableValueList*) _tmp52_);
#line 219 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (_tmp53_, "v.vals.is_value ()");
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp54_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp55_ = _tmp54_;
#line 220 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	serializable_property_value_list_test_values_set_string (_tmp55_, "K1");
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp56_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp57_ = _tmp56_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp58_ = serializable_property_value_list_test_values_get_string (_tmp57_);
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp59_ = _tmp58_;
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (g_strcmp0 (_tmp59_, "K1") == 0, "v.vals.get_string () == \"K1\"");
#line 221 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (_tmp59_);
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp60_ = serializable_property_value_list_test_value_list_get_vals (v);
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp61_ = _tmp60_;
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp62_ = gxml_serializable_value_list_is_value ((GXmlSerializableValueList*) _tmp61_);
#line 222 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_vala_assert (!_tmp62_, "!v.vals.is_value ()");
#line 201 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_object_unref0 (v);
#line 2248 "SerializablePropertyValueListTest.c"
}


static void ___lambda152__gtest_func (void) {
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	__lambda152_ ();
#line 2255 "SerializablePropertyValueListTest.c"
}


static void __lambda153_ (void) {
	GError * _inner_error_ = NULL;
	{
		SerializablePropertyValueListTestValueList* vl = NULL;
		SerializablePropertyValueListTestValueList* _tmp0_ = NULL;
		SerializablePropertyValueListTestValues* _tmp1_ = NULL;
		SerializablePropertyValueListTestValues* _tmp2_ = NULL;
		SerializablePropertyValueListTestValues* _tmp3_ = NULL;
		SerializablePropertyValueListTestValues* _tmp4_ = NULL;
		GXmlGDocument* doc = NULL;
		GXmlGDocument* _tmp5_ = NULL;
		GXmlNode* _tmp6_ = NULL;
		GXmlNode* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlElement* element = NULL;
		GXmlNode* _tmp12_ = NULL;
		GXmlNode* _tmp13_ = NULL;
		GXmlElement* _tmp14_ = NULL;
		GXmlNode* s = NULL;
		GXmlNode* _tmp15_ = NULL;
		GXmlNode* i = NULL;
		GeeMap* _tmp16_ = NULL;
		GeeMap* _tmp17_ = NULL;
		GeeMap* _tmp18_ = NULL;
		gpointer _tmp19_ = NULL;
		GXmlNode* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		GXmlNode* evl1 = NULL;
		GeeMap* _tmp24_ = NULL;
		GeeMap* _tmp25_ = NULL;
		GeeMap* _tmp26_ = NULL;
		gpointer _tmp27_ = NULL;
		GXmlNode* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp0_ = serializable_property_value_list_test_value_list_new ();
#line 227 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		vl = _tmp0_;
#line 228 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp1_ = serializable_property_value_list_test_values_new ();
#line 228 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp2_ = _tmp1_;
#line 228 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_vals (vl, _tmp2_);
#line 228 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp2_);
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp3_ = serializable_property_value_list_test_value_list_get_vals (vl);
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp4_ = _tmp3_;
#line 229 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		gxml_serializable_value_list_select_value_at ((GXmlSerializableValueList*) _tmp4_, (gint) SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL1);
#line 230 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp5_ = gxml_gdocument_new ();
#line 230 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		doc = _tmp5_;
#line 231 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp6_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) vl, (GXmlNode*) doc, &_inner_error_);
#line 231 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp7_ = _tmp6_;
#line 231 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp7_);
#line 231 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 231 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (doc);
#line 231 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (vl);
#line 2337 "SerializablePropertyValueListTest.c"
			goto __catch40_g_error;
		}
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp8_ = gxml_gnode_to_string ((GXmlGNode*) doc);
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp9_ = _tmp8_;
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp10_ = g_strconcat ("XML:\n", _tmp9_, NULL);
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp11_ = _tmp10_;
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp11_);
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp11_);
#line 232 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp9_);
#line 233 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 233 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp13_ = _tmp12_;
#line 233 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, GXML_TYPE_ELEMENT) ? ((GXmlElement*) _tmp13_) : NULL;
#line 233 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		if (_tmp14_ == NULL) {
#line 233 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
			_g_object_unref0 (_tmp13_);
#line 2364 "SerializablePropertyValueListTest.c"
		}
#line 233 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		element = _tmp14_;
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp15_ = gxml_element_get_attr (element, "name");
#line 234 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		s = _tmp15_;
#line 235 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (s == NULL, "s == null");
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp16_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp17_ = _tmp16_;
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp18_ = _tmp17_;
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp19_ = gee_map_get (_tmp18_, "integer");
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp20_ = (GXmlNode*) _tmp19_;
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp18_);
#line 236 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		i = _tmp20_;
#line 237 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp21_ = gxml_node_get_value (i);
#line 237 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp22_ = _tmp21_;
#line 237 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp23_ = _tmp22_;
#line 237 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "0") == 0, "i.value == \"0\"");
#line 237 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp23_);
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp24_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp25_ = _tmp24_;
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp26_ = _tmp25_;
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp27_ = gee_map_get (_tmp26_, "vals");
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp28_ = (GXmlNode*) _tmp27_;
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (_tmp26_);
#line 238 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		evl1 = _tmp28_;
#line 239 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (evl1 != NULL, "evl1 != null");
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp29_ = gxml_node_get_value (evl1);
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp30_ = _tmp29_;
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp31_ = _tmp30_;
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (_tmp31_ != NULL, "evl1.value != null");
#line 240 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp31_);
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp32_ = gxml_node_get_value (evl1);
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp33_ = _tmp32_;
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp34_ = _tmp33_;
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "Val1") == 0, "evl1.value == \"Val1\"");
#line 241 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp34_);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (evl1);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (i);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (s);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (element);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (doc);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_object_unref0 (vl);
#line 2446 "SerializablePropertyValueListTest.c"
	}
	goto __finally40;
	__catch40_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		e = _inner_error_;
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_inner_error_ = NULL;
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp35_ = e->message;
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp36_ = string_to_string (_tmp35_);
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp37_ = g_strconcat ("ERROR: ", _tmp36_, NULL);
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_tmp38_ = _tmp37_;
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_test_message ("%s", _tmp38_);
#line 243 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_free0 (_tmp38_);
#line 244 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_assert_not_reached ();
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		_g_error_free0 (e);
#line 2476 "SerializablePropertyValueListTest.c"
	}
	__finally40:
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_clear_error (&_inner_error_);
#line 226 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		return;
#line 2487 "SerializablePropertyValueListTest.c"
	}
}


static void ___lambda153__gtest_func (void) {
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	__lambda153_ ();
#line 2495 "SerializablePropertyValueListTest.c"
}


void serializable_property_value_list_test_add_tests (void) {
#line 54 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_test_add_func ("/gxml/serializable/ValueList/basic", ___lambda148__gtest_func);
#line 75 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_test_add_func ("/gxml/serializable/ValueList/changes", ___lambda149__gtest_func);
#line 128 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_test_add_func ("/gxml/serializable/ValueList/deserialize", ___lambda150__gtest_func);
#line 147 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_test_add_func ("/gxml/serializable/ValueList/no-name", ___lambda151__gtest_func);
#line 200 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_test_add_func ("/gxml/serializable/ValueList/fixed/basic", ___lambda152__gtest_func);
#line 224 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_test_add_func ("/gxml/serializable/ValueList/fixed/serialize", ___lambda153__gtest_func);
#line 2512 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTest* serializable_property_value_list_test_construct (GType object_type) {
	SerializablePropertyValueListTest* self = NULL;
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = (SerializablePropertyValueListTest*) gxml_test_construct (object_type);
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return self;
#line 2522 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTest* serializable_property_value_list_test_new (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return serializable_property_value_list_test_construct (TYPE_SERIALIZABLE_PROPERTY_VALUE_LIST_TEST);
#line 2529 "SerializablePropertyValueListTest.c"
}


GType serializable_property_value_list_test_values_enum_get_type (void) {
	static volatile gsize serializable_property_value_list_test_values_enum_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_value_list_test_values_enum_type_id__volatile)) {
		static const GEnumValue values[] = {{SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL1, "SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL1", "val1"}, {SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL2, "SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUES_ENUM_VAL2", "val2"}, {0, NULL, NULL}};
		GType serializable_property_value_list_test_values_enum_type_id;
		serializable_property_value_list_test_values_enum_type_id = g_enum_register_static ("SerializablePropertyValueListTestValuesEnum", values);
		g_once_init_leave (&serializable_property_value_list_test_values_enum_type_id__volatile, serializable_property_value_list_test_values_enum_type_id);
	}
	return serializable_property_value_list_test_values_enum_type_id__volatile;
}


void serializable_property_value_list_test_values_select (SerializablePropertyValueListTestValues* self, SerializablePropertyValueListTestValuesEnum v) {
	SerializablePropertyValueListTestValuesEnum _tmp0_ = 0;
#line 33 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (self != NULL);
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = v;
#line 35 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	gxml_serializable_value_list_select_value_at ((GXmlSerializableValueList*) self, (gint) _tmp0_);
#line 2553 "SerializablePropertyValueListTest.c"
}


gchar* serializable_property_value_list_test_values_get_string (SerializablePropertyValueListTestValues* self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = gxml_serializable_property_get_serializable_property_value ((GXmlSerializableProperty*) self);
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp0_;
#line 37 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2568 "SerializablePropertyValueListTest.c"
}


void serializable_property_value_list_test_values_set_string (SerializablePropertyValueListTestValues* self, const gchar* str) {
	const gchar* _tmp0_ = NULL;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (self != NULL);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (str != NULL);
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = str;
#line 38 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	gxml_serializable_property_set_serializable_property_value ((GXmlSerializableProperty*) self, _tmp0_);
#line 2582 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTestValues* serializable_property_value_list_test_values_construct (GType object_type) {
	SerializablePropertyValueListTestValues * self = NULL;
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = (SerializablePropertyValueListTestValues*) gxml_serializable_value_list_construct (object_type);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return self;
#line 2592 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTestValues* serializable_property_value_list_test_values_new (void) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return serializable_property_value_list_test_values_construct (SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES);
#line 2599 "SerializablePropertyValueListTest.c"
}


static GObject * serializable_property_value_list_test_values_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	SerializablePropertyValueListTestValues * self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	parent_class = G_OBJECT_CLASS (serializable_property_value_list_test_values_parent_class);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES, SerializablePropertyValueListTestValues);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = g_strdup ("Val1");
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp1_ = g_strdup ("Val2");
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp2_[0] = _tmp0_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp2_[1] = _tmp1_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	((GXmlSerializableValueList*) self)->_vals = (_vala_array_free (((GXmlSerializableValueList*) self)->_vals, ((GXmlSerializableValueList*) self)->_vals_length1, (GDestroyNotify) g_free), NULL);
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	((GXmlSerializableValueList*) self)->_vals = _tmp2_;
#line 31 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	((GXmlSerializableValueList*) self)->_vals_length1 = 2;
#line 30 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return obj;
#line 2634 "SerializablePropertyValueListTest.c"
}


static void serializable_property_value_list_test_values_class_init (SerializablePropertyValueListTestValuesClass * klass) {
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	serializable_property_value_list_test_values_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	G_OBJECT_CLASS (klass)->constructor = serializable_property_value_list_test_values_constructor;
#line 2643 "SerializablePropertyValueListTest.c"
}


static void serializable_property_value_list_test_values_instance_init (SerializablePropertyValueListTestValues * self) {
}


GType serializable_property_value_list_test_values_get_type (void) {
	static volatile gsize serializable_property_value_list_test_values_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_value_list_test_values_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyValueListTestValuesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_value_list_test_values_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyValueListTestValues), 0, (GInstanceInitFunc) serializable_property_value_list_test_values_instance_init, NULL };
		GType serializable_property_value_list_test_values_type_id;
		serializable_property_value_list_test_values_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_VALUE_LIST, "SerializablePropertyValueListTestValues", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_value_list_test_values_type_id__volatile, serializable_property_value_list_test_values_type_id);
	}
	return serializable_property_value_list_test_values_type_id__volatile;
}


static gchar* serializable_property_value_list_test_value_list_real_node_name (GXmlSerializableObjectModel* base) {
	SerializablePropertyValueListTestValueList * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = (SerializablePropertyValueListTestValueList*) base;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = g_strdup ("options");
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp0_;
#line 50 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2675 "SerializablePropertyValueListTest.c"
}


static gchar* serializable_property_value_list_test_value_list_real_to_string (GXmlSerializableObjectModel* base) {
	SerializablePropertyValueListTestValueList * self;
	gchar* result = NULL;
	GType _tmp0_ = 0UL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = (SerializablePropertyValueListTestValueList*) base;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = G_TYPE_FROM_INSTANCE ((GObject*) self);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp1_ = g_type_name (_tmp0_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp2_;
#line 51 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2697 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTestValueList* serializable_property_value_list_test_value_list_construct (GType object_type) {
	SerializablePropertyValueListTestValueList * self = NULL;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = (SerializablePropertyValueListTestValueList*) gxml_serializable_object_model_construct (object_type);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return self;
#line 2707 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTestValueList* serializable_property_value_list_test_value_list_new (void) {
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return serializable_property_value_list_test_value_list_construct (SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST);
#line 2714 "SerializablePropertyValueListTest.c"
}


GXmlSerializableValueList* serializable_property_value_list_test_value_list_get_values (SerializablePropertyValueListTestValueList* self) {
	GXmlSerializableValueList* result;
	GXmlSerializableValueList* _tmp0_ = NULL;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = self->priv->_values;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp0_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2729 "SerializablePropertyValueListTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 2736 "SerializablePropertyValueListTest.c"
}


void serializable_property_value_list_test_value_list_set_values (SerializablePropertyValueListTestValueList* self, GXmlSerializableValueList* value) {
	GXmlSerializableValueList* _tmp0_ = NULL;
	GXmlSerializableValueList* _tmp1_ = NULL;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (self != NULL);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = value;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_object_unref0 (self->priv->_values);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self->priv->_values = _tmp1_;
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_notify ((GObject *) self, "values");
#line 2755 "SerializablePropertyValueListTest.c"
}


SerializablePropertyValueListTestValues* serializable_property_value_list_test_value_list_get_vals (SerializablePropertyValueListTestValueList* self) {
	SerializablePropertyValueListTestValues* result;
	SerializablePropertyValueListTestValues* _tmp0_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = self->priv->_vals;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2770 "SerializablePropertyValueListTest.c"
}


void serializable_property_value_list_test_value_list_set_vals (SerializablePropertyValueListTestValueList* self, SerializablePropertyValueListTestValues* value) {
	SerializablePropertyValueListTestValues* _tmp0_ = NULL;
	SerializablePropertyValueListTestValues* _tmp1_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = value;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_object_unref0 (self->priv->_vals);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self->priv->_vals = _tmp1_;
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_notify ((GObject *) self, "vals");
#line 2789 "SerializablePropertyValueListTest.c"
}


gint serializable_property_value_list_test_value_list_get_integer (SerializablePropertyValueListTestValueList* self) {
	gint result;
	gint _tmp0_ = 0;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = self->priv->_integer;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2804 "SerializablePropertyValueListTest.c"
}


void serializable_property_value_list_test_value_list_set_integer (SerializablePropertyValueListTestValueList* self, gint value) {
	gint _tmp0_ = 0;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (self != NULL);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = value;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self->priv->_integer = _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_notify ((GObject *) self, "integer");
#line 2818 "SerializablePropertyValueListTest.c"
}


const gchar* serializable_property_value_list_test_value_list_get_name (SerializablePropertyValueListTestValueList* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = self->priv->_name;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	result = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	return result;
#line 2833 "SerializablePropertyValueListTest.c"
}


void serializable_property_value_list_test_value_list_set_name (SerializablePropertyValueListTestValueList* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp0_ = value;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (self->priv->_name);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self->priv->_name = _tmp1_;
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 2852 "SerializablePropertyValueListTest.c"
}


static void serializable_property_value_list_test_value_list_class_init (SerializablePropertyValueListTestValueListClass * klass) {
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	serializable_property_value_list_test_value_list_parent_class = g_type_class_peek_parent (klass);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_type_class_add_private (klass, sizeof (SerializablePropertyValueListTestValueListPrivate));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->node_name = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_value_list_test_value_list_real_node_name;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	((GXmlSerializableObjectModelClass *) klass)->to_string = (gchar* (*)(GXmlSerializableObjectModel*)) serializable_property_value_list_test_value_list_real_to_string;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_serializable_property_value_list_test_value_list_get_property;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_serializable_property_value_list_test_value_list_set_property;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	G_OBJECT_CLASS (klass)->finalize = serializable_property_value_list_test_value_list_finalize;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALUES, g_param_spec_object ("values", "values", "values", GXML_TYPE_SERIALIZABLE_VALUE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALS, g_param_spec_object ("vals", "vals", "vals", SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUES, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_INTEGER, g_param_spec_int ("integer", "integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2879 "SerializablePropertyValueListTest.c"
}


static void serializable_property_value_list_test_value_list_instance_init (SerializablePropertyValueListTestValueList * self) {
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self->priv = SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_GET_PRIVATE (self);
#line 48 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self->priv->_integer = 0;
#line 2888 "SerializablePropertyValueListTest.c"
}


static void serializable_property_value_list_test_value_list_finalize (GObject* obj) {
	SerializablePropertyValueListTestValueList * self;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueList);
#line 46 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_object_unref0 (self->priv->_values);
#line 47 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_object_unref0 (self->priv->_vals);
#line 49 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	_g_free0 (self->priv->_name);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	G_OBJECT_CLASS (serializable_property_value_list_test_value_list_parent_class)->finalize (obj);
#line 2904 "SerializablePropertyValueListTest.c"
}


GType serializable_property_value_list_test_value_list_get_type (void) {
	static volatile gsize serializable_property_value_list_test_value_list_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_value_list_test_value_list_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyValueListTestValueListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_value_list_test_value_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyValueListTestValueList), 0, (GInstanceInitFunc) serializable_property_value_list_test_value_list_instance_init, NULL };
		GType serializable_property_value_list_test_value_list_type_id;
		serializable_property_value_list_test_value_list_type_id = g_type_register_static (GXML_TYPE_SERIALIZABLE_OBJECT_MODEL, "SerializablePropertyValueListTestValueList", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_value_list_test_value_list_type_id__volatile, serializable_property_value_list_test_value_list_type_id);
	}
	return serializable_property_value_list_test_value_list_type_id__volatile;
}


static void _vala_serializable_property_value_list_test_value_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SerializablePropertyValueListTestValueList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueList);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	switch (property_id) {
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALUES:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_value_set_object (value, serializable_property_value_list_test_value_list_get_values (self));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALS:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_value_set_object (value, serializable_property_value_list_test_value_list_get_vals (self));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_INTEGER:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_value_set_int (value, serializable_property_value_list_test_value_list_get_integer (self));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_NAME:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		g_value_set_string (value, serializable_property_value_list_test_value_list_get_name (self));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 2949 "SerializablePropertyValueListTest.c"
		default:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 2955 "SerializablePropertyValueListTest.c"
	}
}


static void _vala_serializable_property_value_list_test_value_list_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SerializablePropertyValueListTestValueList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_TYPE_VALUE_LIST, SerializablePropertyValueListTestValueList);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	switch (property_id) {
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALUES:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_values (self, g_value_get_object (value));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_VALS:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_vals (self, g_value_get_object (value));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_INTEGER:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_integer (self, g_value_get_int (value));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		case SERIALIZABLE_PROPERTY_VALUE_LIST_TEST_VALUE_LIST_NAME:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		serializable_property_value_list_test_value_list_set_name (self, g_value_get_string (value));
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 2989 "SerializablePropertyValueListTest.c"
		default:
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 44 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
		break;
#line 2995 "SerializablePropertyValueListTest.c"
	}
}


static void serializable_property_value_list_test_class_init (SerializablePropertyValueListTestClass * klass) {
#line 27 "/home/despinosa/Proyectos/gxml/test/SerializablePropertyValueListTest.vala"
	serializable_property_value_list_test_parent_class = g_type_class_peek_parent (klass);
#line 3003 "SerializablePropertyValueListTest.c"
}


static void serializable_property_value_list_test_instance_init (SerializablePropertyValueListTest * self) {
}


/**
 *
 *  SerializablePropertyValueListTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType serializable_property_value_list_test_get_type (void) {
	static volatile gsize serializable_property_value_list_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_property_value_list_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializablePropertyValueListTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_property_value_list_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializablePropertyValueListTest), 0, (GInstanceInitFunc) serializable_property_value_list_test_instance_init, NULL };
		GType serializable_property_value_list_test_type_id;
		serializable_property_value_list_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializablePropertyValueListTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_property_value_list_test_type_id__volatile, serializable_property_value_list_test_type_id);
	}
	return serializable_property_value_list_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



